! MODULE       : livestock_parameters_var
!
! CONTACT      : orchidee-help _at_ listes.ipsl.fr
!
! LICENCE      : IPSL (2011)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>BRIEF        This module contains the variables in function of livestock type (livestock).
!!
!! DESCRIPTION: This module contains the declarations for the externalized variables in function of the
!!                livestock type(livestock).

!!                The module is already USE in module livestock_parameters. Therefor no need to USE it seperatly except
!!                if the subroutines in module livestock_parameters are not needed.

!!
!! RECENT CHANGE(S): None
!!
!! REFERENCE(S) : None
!!
!! SVN          :
!! $HeadURL: $
!! $Date: $
!! $Revision: $
!!

!_ ================================================================================================================================

MODULE livestock_parameters_var

  USE defprec

  IMPLICIT NONE
 INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: livestock_to_lmtc  !! Table of conversion : we associate one pft to one metaclass
                                                                 !! (1-13, unitless)
!$OMP THREADPRIVATE(livestock_to_lmtc)

 LOGICAL, SAVE   :: l_first_livestock_parameters = .TRUE.             !! To keep first call trace of the module (true/false)
!$OMP THREADPRIVATE(l_first_livestock_parameters)

  INTEGER(i_std), SAVE   ::  nlm = 5	!! Number of MTCS fixed in the code (unitless)
!$OMP THREADPRIVATE(nlm)


  CHARACTER(len=34), ALLOCATABLE, SAVE, DIMENSION(:)   ::  LIVESTOCK_name	!! description of the MTC (unitless)
								!  1
								!  2
								!  3
								!  4
								!  5
!$OMP THREADPRIVATE(LIVESTOCK_name)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:)           :: is_ruminant             !! flag for ruminant animal types (true/false)
  !$OMP THREADPRIVATE(is_ruminant)

  REAL(r_std),ALLOCATABLE, SAVE                      :: max_above             !! Max aboveground biomass fraction that can be extracted (unitless)
  !$OMP THREADPRIVATE(max_above)
  !
  ! ANIMAL CHARACTERISTICS
  !

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  weight_euref	!! European weight references  (kg)
								!! used in case of normalizing litter amount
!$OMP THREADPRIVATE(weight_euref)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)   ::  xexcreted	!! proportion of N excreted calculated from (1-Nretained)
								!! Nretained : fraction of nitrogen retained by the animal
!$OMP THREADPRIVATE(xexcreted)
                                                                         !! for the production of meat, milk, or wood

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  xurine	!! Proportion of TAN in N excreted
!$OMP THREADPRIVATE(xurine)
  !
  ! ACTIVITIES CHARACTERISTICS
  !

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  straw_euref	!! European straw used in litter-based manure
								!! management systems  (kg /Heads/yr)
!$OMP THREADPRIVATE(straw_euref)
                                                                        !! used only for Europe region?

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  n_straw_euref	!! European N added in straw-litter
								!! (kg N /Heads/yr)
!$OMP THREADPRIVATE(n_straw_euref)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  length_euref	!! European length of housing (days)
!$OMP THREADPRIVATE(length_euref)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  xgrazing	!! Fraction of the year where
								!! animal graze (European)
!$OMP THREADPRIVATE(xgrazing)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  xyard	!! Fraction of the year where
								!! animal is at yard (European)
!$OMP THREADPRIVATE(xyard)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  graz_period   !! Period (in days) where
                                !! animal is at grazing (European)
!$OMP THREADPRIVATE(graz_period)



  !
  ! MANURE INFORMATION
  !

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  xmin	!! Fraction of mineralized organic N
								!! present in manure stored
!$OMP THREADPRIVATE(xmin)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ximm	!! Fraction of TAN that is immobilized in
							                                        	!! organic matter when manure is handled as straw-based solid manure
!$OMP THREADPRIVATE(ximm)
  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:,:)   ::  ef_hou	!! Emission factor of TAN during
                                                              !! housing in manure
!$OMP THREADPRIVATE(ef_hou)

REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_hou_s	!! Emission factor of TAN during
              !! housing in solid manure
!$OMP THREADPRIVATE(ef_hou_s)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_hou_l	!! Emission factor of TAN during
								!! housing in liquid manure
!$OMP THREADPRIVATE(ef_hou_l)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_yard	!! Emission factor of TAN when
								!! animal is at yard
!$OMP THREADPRIVATE(ef_yard)
 REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:,:,:)   ::  ef_sto	!! Emission factor of TAN during
                                                             !! storage in manure
!$OMP THREADPRIVATE(ef_sto)
  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_sto_l	!! Emission factor of TAN during
								!! storage in liquid manure
!$OMP THREADPRIVATE(ef_sto_l)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_sto_s	!! Emission factor of TAN during
								!! storage in solid manure
!$OMP THREADPRIVATE(ef_sto_s)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_n2o_sto_l	!! Emission factor of N2O during
								!! storage in liquid manure
!$OMP THREADPRIVATE(ef_n2o_sto_l)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_n2o_sto_s	!! Emission factor of N2O during
								!! storage in solid manure
!$OMP THREADPRIVATE(ef_n2o_sto_s)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_no_sto_l	!! Emission factor of NO during
								!! storage in liquid manure
!$OMP THREADPRIVATE(ef_no_sto_l)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_no_sto_s	!! Emission factor of NO during
								!! storage in solid manure
!$OMP THREADPRIVATE(ef_no_sto_s)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_n2_sto_l	!! Emission factor of N2 during
								!! storage in liquid manure
!$OMP THREADPRIVATE(ef_n2_sto_l)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_n2_sto_s	!! Emission factor of N2 during
								!! storage in solid manure
!$OMP THREADPRIVATE(ef_n2_sto_s)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_app_l	!! Emission factor of TAN during
								!! application of liquid manure
!$OMP THREADPRIVATE(ef_app_l)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_app_s	!! Emission factor of TAN during
								!! application of solid manure
!$OMP THREADPRIVATE(ef_app_s)

  REAL(r_std),ALLOCATABLE, SAVE, DIMENSION(:)   ::  ef_graz	!! Emission factor of TAN during
								!! grazing
!$OMP THREADPRIVATE(ef_graz)




END MODULE livestock_parameters_var
